complete -c authoscope -n "__fish_use_subcommand" -s n -l workers -d 'Concurrent workers'
complete -c authoscope -n "__fish_use_subcommand" -s o -l output -d 'Write results to file'
complete -c authoscope -n "__fish_use_subcommand" -s v -l verbose -d 'Verbose output'
complete -c authoscope -n "__fish_use_subcommand" -s h -l help -d 'Prints help information'
complete -c authoscope -n "__fish_use_subcommand" -s V -l version -d 'Prints version information'
complete -c authoscope -n "__fish_use_subcommand" -f -a "dict" -d 'For each user try every password from a dictionary/wordlist'
complete -c authoscope -n "__fish_use_subcommand" -f -a "combo" -d 'Run a credential stuffing attack with a combolist'
complete -c authoscope -n "__fish_use_subcommand" -f -a "enum" -d 'For each user enumerate if an account exists with that name/email'
complete -c authoscope -n "__fish_use_subcommand" -f -a "run" -d 'Run a script with a single username and password'
complete -c authoscope -n "__fish_use_subcommand" -f -a "fsck" -d 'Verify a given input file is properly encoded and all entries have valid formatting'
complete -c authoscope -n "__fish_use_subcommand" -f -a "completions" -d 'Generate shell completions'
complete -c authoscope -n "__fish_use_subcommand" -f -a "help" -d 'Prints this message or the help of the given subcommand(s)'
complete -c authoscope -n "__fish_seen_subcommand_from dict" -s h -l help -d 'Prints help information'
complete -c authoscope -n "__fish_seen_subcommand_from dict" -s V -l version -d 'Prints version information'
complete -c authoscope -n "__fish_seen_subcommand_from dict" -s v -l verbose -d 'Verbose output'
complete -c authoscope -n "__fish_seen_subcommand_from combo" -s h -l help -d 'Prints help information'
complete -c authoscope -n "__fish_seen_subcommand_from combo" -s V -l version -d 'Prints version information'
complete -c authoscope -n "__fish_seen_subcommand_from combo" -s v -l verbose -d 'Verbose output'
complete -c authoscope -n "__fish_seen_subcommand_from enum" -s h -l help -d 'Prints help information'
complete -c authoscope -n "__fish_seen_subcommand_from enum" -s V -l version -d 'Prints version information'
complete -c authoscope -n "__fish_seen_subcommand_from enum" -s v -l verbose -d 'Verbose output'
complete -c authoscope -n "__fish_seen_subcommand_from run" -s x -l exitcode -d 'Set the exitcode to 2 if the credentials are invalid'
complete -c authoscope -n "__fish_seen_subcommand_from run" -s h -l help -d 'Prints help information'
complete -c authoscope -n "__fish_seen_subcommand_from run" -s V -l version -d 'Prints version information'
complete -c authoscope -n "__fish_seen_subcommand_from run" -s v -l verbose -d 'Verbose output'
complete -c authoscope -n "__fish_seen_subcommand_from fsck" -s q -l quiet -d 'Do not show invalid lines'
complete -c authoscope -n "__fish_seen_subcommand_from fsck" -s s -l silent -d 'Do not show valid lines'
complete -c authoscope -n "__fish_seen_subcommand_from fsck" -s c -l colon -d 'Require one colon per line'
complete -c authoscope -n "__fish_seen_subcommand_from fsck" -s h -l help -d 'Prints help information'
complete -c authoscope -n "__fish_seen_subcommand_from fsck" -s V -l version -d 'Prints version information'
complete -c authoscope -n "__fish_seen_subcommand_from fsck" -s v -l verbose -d 'Verbose output'
complete -c authoscope -n "__fish_seen_subcommand_from completions" -s h -l help -d 'Prints help information'
complete -c authoscope -n "__fish_seen_subcommand_from completions" -s V -l version -d 'Prints version information'
complete -c authoscope -n "__fish_seen_subcommand_from completions" -s v -l verbose -d 'Verbose output'
complete -c authoscope -n "__fish_seen_subcommand_from help" -s h -l help -d 'Prints help information'
complete -c authoscope -n "__fish_seen_subcommand_from help" -s V -l version -d 'Prints version information'
complete -c authoscope -n "__fish_seen_subcommand_from help" -s v -l verbose -d 'Verbose output'
